==> gatsby-source-netlify-cms-0.9.3.tgz: package/on-pre-bootstrap.js <==
"use strict";

const fs = require('fs-extra');

const path = require('path');

const mkdirp = require('mkdirp');

module.exports = (props, options) => {
  const {
    store,
    reporter
  } = props;
  const {
    program
  } = store.getState();
  const {
    config,
    copyRootPath = path.dirname(require.resolve('./'))
  } = options || {};
  const rootDir = `${path.resolve(copyRootPath)}`;
  const programDir = `${path.resolve(program.directory)}`;
  const okToCopy = rootDir !== programDir;

  if (typeof config !== 'object') {
    reporter.panic('[gatsby-source-netlify-cms] options.config must be a json object');
  }

  if (!Array.isArray(config.collections)) {
    reporter.panic('[gatsby-source-netlify-cms] collections missing from config');
  }

  const debug = options.debug ? reporter.info : () => {
    return;
  };
  /*
    Confirm or create media_folder directory
    if it exists in the config
  */

  if (config.media_folder) {
    const mediaDir = path.join(programDir, `./${config.media_folder}`);

    if (!fs.existsSync(mediaDir)) {
      mkdirp.sync(mediaDir);
      reporter.info(`Created: ${mediaDir}`);
      const copyDir = path.join(rootDir, `./${config.media_folder}`);

      if (okToCopy && fs.existsSync(copyDir)) {
        fs.copySync(copyDir, mediaDir);
        reporter.warn(`Copied demo media to ${config.media_folder}`);
      }
    }
  }
  /*
    Confirm or create collections file/files directories
  */


  config.collections.forEach(collection => {
    if (collection.folder) {
      const dir = path.join(programDir, `./${collection.folder}`);

      if (!fs.existsSync(dir)) {
        mkdirp.sync(dir);
        reporter.warn(`Collection directory created: ${dir}`);
        const copyDir = path.join(rootDir, `./${collection.folder}`);

        if (okToCopy && fs.existsSync(copyDir)) {
          fs.copySync(copyDir, dir);
          reporter.warn(`Copied demo files to ${collection.folder}`);
        }
      }
    } else {
      collection.files.forEach(item => {
        const filePath = path.join(programDir, `./${item.file}`);
        const dir = path.dirname(filePath);

        if (!fs.existsSync(dir)) {
          mkdirp.sync(dir);
          reporter.warn(`File directory created: ${dir}`);
        }

        if (!fs.existsSync(filePath)) {
          // Create the missing file from copy or empty
          const copyFile = path.join(rootDir, `./${item.file}`);

          if (okToCopy && fs.existsSync(copyFile)) {
            fs.copySync(copyFile, filePath);
            reporter.warn(`Copied demo file: ${item.file}`);
          } else {
            fs.writeFileSync(filePath, '', {
              flag: 'w',
              encoding: 'utf8'
            });
            reporter.warn(`Empty file created: ${filePath}`);
          }
        }
      });
    }
  });
};

==> gatsby-source-netlify-cms-0.10.5.tgz: package/on-pre-bootstrap.js <==
"use strict";

const fs = require("fs-extra");

const path = require("path");

const mkdirp = require("mkdirp");

module.exports = (props, options) => {
  const {
    store,
    reporter
  } = props;
  const {
    program
  } = store.getState();
  const {
    config,
    copyRootPath = path.dirname(require.resolve("./"))
  } = options || {};
  const rootDir = `${path.resolve(copyRootPath)}`;
  const programDir = `${path.resolve(program.directory)}`;
  const okToCopy = rootDir !== programDir;

  if (typeof config !== "object") {
    reporter.panic("[gatsby-source-netlify-cms] options.config must be a json object");
  }

  if (!Array.isArray(config.collections)) {
    reporter.panic("[gatsby-source-netlify-cms] collections missing from config");
  }

  const debug = options.debug ? reporter.info : () => {
    return;
  };
  /*
    Confirm or create media_folder directory
    if it exists in the config
  */

  if (config.media_folder) {
    const mediaDir = path.join(programDir, `./${config.media_folder}`);

    if (!fs.existsSync(mediaDir)) {
      mkdirp.sync(mediaDir);
      reporter.info(`Created: ${mediaDir}`);
      const copyDir = path.join(rootDir, `./${config.media_folder}`);

      if (okToCopy && fs.existsSync(copyDir)) {
        fs.copySync(copyDir, mediaDir);
        reporter.info(`Copied demo media to ${config.media_folder}`);
      }
    }
  }
  /*
    Confirm or create collections file/files directories
  */


  config.collections.forEach(collection => {
    if (collection.folder) {
      const dir = path.join(programDir, `./${collection.folder}`);

      if (!fs.existsSync(dir)) {
        mkdirp.sync(dir);
        reporter.info(`Collection directory created: ${dir}`);
        const copyDir = path.join(rootDir, `./${collection.folder}`);

        if (okToCopy && fs.existsSync(copyDir)) {
          fs.copySync(copyDir, dir);
          reporter.info(`Copied demo files to ${collection.folder}`);
        }
      }
    } else {
      collection.files.forEach(item => {
        const filePath = path.join(programDir, `./${item.file}`);
        const dir = path.dirname(filePath);

        if (!fs.existsSync(dir)) {
          mkdirp.sync(dir);
          reporter.info(`File directory created: ${dir}`);
        }

        if (!fs.existsSync(filePath)) {
          // Create the missing file from copy or empty
          const copyFile = path.join(rootDir, `./${item.file}`);

          if (okToCopy && fs.existsSync(copyFile)) {
            fs.copySync(copyFile, filePath);
            reporter.info(`Copied demo file: ${item.file}`);
          } else {
            fs.writeFileSync(filePath, "", {
              flag: "w",
              encoding: "utf8"
            });
            reporter.warn(`Empty file created: ${filePath}`);
          }
        }
      });
    }
  });
};
